<?php

/*-----------------------------------------------------------------------------------*/

/*	Options Framework

/*-----------------------------------------------------------------------------------*/


// You can mess with these 2 if you wish.

define('OPTIONS', 'of_options'); // Name of the database row where your options are stored

/* Options Framework */
require_once('admin/index.php');


/*-----------------------------------------------------------------------------------*/

/*	Theme Setup

/*-----------------------------------------------------------------------------------*/

function gp_setup() {

	// Add post-formats
	add_theme_support('post-formats', array('gallery', 'video', 'audio', 'product'));
	add_post_type_support('post', 'post-formats');

	// Add language supports.
	load_theme_textdomain('gp');

	// Add post thumbnail supports. http://codex.wordpress.org/Post_Thumbnails
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );

	/* Homepage Default */
	add_image_size( 'gp-200x155', 200, 155, true );
	add_image_size( 'gp-580x250', 580, 250, true );

	/* Featured Posts */
	add_image_size( 'gp-560x280', 560, 280, true );
	add_image_size( 'gp-296x280', 296, 280, true );

	/* Footer Posts */
	add_image_size( 'gp-208x140', 208, 140, true );

	/* Sidebar Widgets */
	add_image_size( 'gp-234x125', 234, 125, true );
	add_image_size( 'gp-90x80', 90, 80, true );

	/* Related Posts */
	add_image_size( 'gp-210x140', 210, 140, true );

	// Add menu supports. http://codex.wordpress.org/Function_Reference/register_nav_menus
	add_theme_support('menus');
	register_nav_menus(array(
		'primary_navigation' => __('Primary Navigation', 'gp'),
		'secondary_navigation' => __('Secondary Navigation', 'gp'),
		'mobile_navigation' => __('Mobile Navigation', 'gp')
	));	
	
	// Functions
	include_once('functions/functions/pagination.php');
	include_once('functions/functions/breadcrumbs.php');
	include_once('functions/functions/gp-metaboxes.php');
	include_once('functions/functions/metabox.php');
	include_once('functions/functions/review.php');
	include_once('woocommerce/woocommerce.php');
	
	// Widgets
	include_once('functions/widgets/recent-posts.php');
	include_once('functions/widgets/tabbed-posts.php');
	include_once('functions/widgets/recent-reviews.php');
	include_once('functions/widgets/newsletter.php');

}

add_action('after_setup_theme', 'gp_setup');


/*-----------------------------------------------------------------------------------*/

/*	Theme Width

/*-----------------------------------------------------------------------------------*/

if ( ! isset( $content_width ) ) {
	$content_width = 710;
}

if ( is_page_template('template-full-width.php') ) { 
	$content_width = 1060;
}

/*-----------------------------------------------------------------------------------*/

/*	Theme Javascripts

/*-----------------------------------------------------------------------------------*/

function gp_theme_js() {

	if(!is_admin()) {
		
		wp_register_script('plugins', get_template_directory_uri() . '/assets/js/plugins.js', array('jquery'), '1.0.0', true );
		wp_register_script('custom', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );

		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'plugins' );
		wp_enqueue_script( 'custom' );
		
		if ( is_singular() ) {
			wp_enqueue_script( 'comment-reply' );
		}
 
		// declare the URL to the file that handles the AJAX request (wp-admin/admin-ajax.php)
		wp_localize_script( 'my-ajax-request', 'MyAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );


	}

}

add_action('wp_enqueue_scripts', 'gp_theme_js');


/*-----------------------------------------------------------------------------------*/

/*	Theme Styles

/*-----------------------------------------------------------------------------------*/

function gp_theme_style()  {  

	wp_register_style( 'styling', get_template_directory_uri() . '/style.css', array(), '1.0.0', 'all' ); 
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/assets/font-awesome/font-awesome.css', array(), '4.2.0', 'all' ); 
	wp_register_style( 'bbpress', get_template_directory_uri() . '/assets/css/bbpress.css', array(), '1.0.0', 'all' ); 
	wp_register_style( 'woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css', array(), '1.0.0', 'all' ); 

	wp_enqueue_style( 'styling' ); 
	wp_enqueue_style( 'fontawesome' ); 

	global $grove_data;
	if(!empty($grove_data['grove_bbpress'])) {
	wp_enqueue_style( 'bbpress' );  
	}
	if(!empty($grove_data['grove_woocommerce'])) {
	wp_enqueue_style( 'woocommerce' );
	}
	
}  

add_action( 'wp_enqueue_scripts', 'gp_theme_style' );  


/*-----------------------------------------------------------------------------------*/

/*	Custom Style

/*-----------------------------------------------------------------------------------*/

function gp_custom_color() {

	get_template_part('assets/custom', 'style');
}

add_action('wp_head', 'gp_custom_color');


/*-----------------------------------------------------------------------------------*/

/*	Widgets Register

/*-----------------------------------------------------------------------------------*/

if(function_exists('register_sidebar')) {

	register_sidebar(array(
		'name' => 'Sidebar Primary Widgets',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Sidebar Secondary Widgets',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));
	
	register_sidebar(array(
		'name' => 'Footer Widgets 1',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 2',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 3',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 4',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'Footer Widgets 5',
		'before_widget' => '<section id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

	register_sidebar(array(
		'name' => 'BBPress Widgets',
		'before_widget' => '<div id="%1$s" class="gp-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="gp-widget-title">',
		'after_title' => '</h4>',
	));

}


/*-----------------------------------------------------------------------------------*/

/*	Browser Classes

/*-----------------------------------------------------------------------------------*/

function browser_body_class($classes) {
    global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
    if($is_lynx) $classes[] = 'lynx';
    elseif($is_gecko) $classes[] = 'gecko';
    elseif($is_opera) $classes[] = 'opera';
    elseif($is_NS4) $classes[] = 'ns4';
    elseif($is_safari) $classes[] = 'safari';
    elseif($is_chrome) $classes[] = 'chrome';
    elseif($is_IE) $classes[] = 'ie';
    else $classes[] = 'unknown';
    if($is_iphone) $classes[] = 'iphone';
    return $classes;
}
add_filter('body_class','browser_body_class');


/*-----------------------------------------------------------------------------------*/

/*	Class to Menus

/*-----------------------------------------------------------------------------------*/

function gp_add_ancestor_class($classlist, $item) {
	global $wp_query, $wpdb;
	//get the ID of the object, to which menu item points
	$id = get_post_meta($item->ID, '_menu_item_object_id', true);
	//get first menu item that is a child of that object
	$children = $wpdb->get_var('SELECT post_id FROM '.$wpdb->postmeta.' WHERE meta_key like "_menu_item_menu_item_parent" AND meta_value='.$item->ID.' LIMIT 1');
	//if there is at least one item, then $children variable will contain it's ID (which is of course more than 0)
	if($children>0)
		//in that case - add the CSS class
		$classlist[]='menu-item-ancestor';
	//return class list
	return $classlist;
}
add_filter('nav_menu_css_class', 'gp_add_ancestor_class', 2, 10);


/*-----------------------------------------------------------------------------------*/

/* Pinterest

/*-----------------------------------------------------------------------------------*/

function catch_that_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
  $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
  $first_img = $matches [1] [0];

  if(empty($first_img)){ //Defines a default image
    $first_img = "/images/default.jpg";
  }
  return $first_img;
}

